pub enum LogFilter {
ShowAll,
HideAll,
ShowPattern(RegexString),
HidePattern(RegexString),
}Expand description
Only log entries matching this filter will be recorded.
Variants
ShowAll
All log entries are recorded.
HideAll
No log entries are recorded.
ShowPattern(RegexString)
Only log entries matching this regular expression are recorded.
HidePattern(RegexString)
Only log entries not matching this regular expression are recorded.
Implementations