pub struct LogEntry<Priority> {
pub timestamp: u64,
pub priority: Priority,
pub file: String,
pub line: u32,
pub message: String,
pub counter: u64,
}Expand description
A single log entry.
Fields
timestamp: u64The time at which the log entry is recorded.
priority: PriorityThe log entry priority level.
file: StringThe source file in which this log entry was generated.
line: u32The line in file in which this log entry was generated.
message: StringThe log message.
counter: u64The index of this entry starting from the last canister upgrade.